#line 5 "bind-lex.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif



#line 9 "bind-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */

/* %if-c-only */
/* %if-not-reentrant */

/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 0
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
    
/* %endif */

/* %if-c-only */

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* %if-c++-only */
/* %endif */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define grecs_bind_const const
#else
#define grecs_bind_const
#endif

/* %not-for-header */

/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (grecs_bind__start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((grecs_bind__start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE grecs_bind_restart(grecs_bind_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(grecs_bind__state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct grecs_bind__buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t grecs_bind__size_t;
#endif

/* %if-not-reentrant */
extern grecs_bind__size_t grecs_bind_leng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
extern FILE *grecs_bind_in, *grecs_bind_out;
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define grecs_bind_less(n) \
	do \
		{ \
		/* Undo effects of setting up grecs_bind_text. */ \
        int grecs_bind_less_macro_arg = (n); \
        YY_LESS_LINENO(grecs_bind_less_macro_arg);\
		*grecs_bind__cp = (grecs_bind__hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(grecs_bind__c_buf_p) = grecs_bind__cp = grecs_bind__bp + grecs_bind_less_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up grecs_bind_text again */ \
		} \
	while ( 0 )

#define unput(c) grecs_bind_unput( c, (grecs_bind_text_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct grecs_bind__buffer_state
	{
/* %if-c-only */
	FILE *grecs_bind__input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *grecs_bind__ch_buf;		/* input buffer */
	char *grecs_bind__buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	grecs_bind__size_t grecs_bind__buf_size;

	/* Number of characters read into grecs_bind__ch_buf, not including EOB
	 * characters.
	 */
	grecs_bind__size_t grecs_bind__n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int grecs_bind__is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int grecs_bind__is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int grecs_bind__at_bol;

    int grecs_bind__bs_lineno; /**< The line count. */
    int grecs_bind__bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int grecs_bind__fill_buffer;

	int grecs_bind__buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via grecs_bind_restart()), so that the user can continue scanning by
	 * just pointing grecs_bind_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

/* %if-not-reentrant */

/* Stack of input buffers. */
static size_t grecs_bind__buffer_stack_top = 0; /**< index of top of stack. */
static size_t grecs_bind__buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * grecs_bind__buffer_stack = 0; /**< Stack as an array. */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (grecs_bind__buffer_stack) \
                          ? (grecs_bind__buffer_stack)[(grecs_bind__buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (grecs_bind__buffer_stack)[(grecs_bind__buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */

/* grecs_bind__hold_char holds the character lost when grecs_bind_text is formed. */
static char grecs_bind__hold_char;
static grecs_bind__size_t grecs_bind__n_chars;		/* number of characters read into grecs_bind__ch_buf */
grecs_bind__size_t grecs_bind_leng;

/* Points to current character in buffer. */
static char *grecs_bind__c_buf_p = (char *) 0;
static int grecs_bind__init = 0;		/* whether we need to initialize */
static int grecs_bind__start = 0;	/* start state number */

/* Flag which is used to allow grecs_bind_wrap()'s to do buffer switches
 * instead of setting up a fresh grecs_bind_in.  A bit of a hack ...
 */
static int grecs_bind__did_buffer_switch_on_eof;
/* %ok-for-header */

/* %endif */

void grecs_bind_restart (FILE *input_file  );
void grecs_bind__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE grecs_bind__create_buffer (FILE *file,int size  );
void grecs_bind__delete_buffer (YY_BUFFER_STATE b  );
void grecs_bind__flush_buffer (YY_BUFFER_STATE b  );
void grecs_bind_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void grecs_bind_pop_buffer_state (void );

static void grecs_bind_ensure_buffer_stack (void );
static void grecs_bind__load_buffer_state (void );
static void grecs_bind__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER grecs_bind__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE grecs_bind__scan_buffer (char *base,grecs_bind__size_t size  );
YY_BUFFER_STATE grecs_bind__scan_string (grecs_bind_const char *grecs_bind__str  );
YY_BUFFER_STATE grecs_bind__scan_bytes (grecs_bind_const char *bytes,grecs_bind__size_t len  );

/* %endif */

void *grecs_bind_alloc (grecs_bind__size_t  );
void *grecs_bind_realloc (void *,grecs_bind__size_t  );
void grecs_bind_free (void *  );

#define grecs_bind__new_buffer grecs_bind__create_buffer

#define grecs_bind__set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        grecs_bind_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            grecs_bind__create_buffer(grecs_bind_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->grecs_bind__is_interactive = is_interactive; \
	}

#define grecs_bind__set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        grecs_bind_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            grecs_bind__create_buffer(grecs_bind_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->grecs_bind__at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->grecs_bind__at_bol)

/* %% [1.0] grecs_bind_text/grecs_bind_in/grecs_bind_out/grecs_bind__state_type/grecs_bind_lineno etc. def's & init go here */
/* Begin user sect3 */

#define FLEX_DEBUG

typedef unsigned char YY_CHAR;

FILE *grecs_bind_in = (FILE *) 0, *grecs_bind_out = (FILE *) 0;

typedef int grecs_bind__state_type;

extern int grecs_bind_lineno;

int grecs_bind_lineno = 1;

extern char *grecs_bind_text;
#ifdef grecs_bind_text_ptr
#undef grecs_bind_text_ptr
#endif
#define grecs_bind_text_ptr grecs_bind_text

/* %% [1.5] DFA */

/* %if-c-only Standard (non-C++) definition */

static grecs_bind__state_type grecs_bind__get_previous_state (void );
static grecs_bind__state_type grecs_bind__try_NUL_trans (grecs_bind__state_type current_state  );
static int grecs_bind__get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void grecs_bind__fatal_error (grecs_bind_const char msg[]  );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up grecs_bind_text.
 */
#define YY_DO_BEFORE_ACTION \
	(grecs_bind_text_ptr) = grecs_bind__bp; \
/* %% [2.0] code to fiddle grecs_bind_text and grecs_bind_leng for grecs_bind_more() goes here \ */\
	grecs_bind_leng = (size_t) (grecs_bind__cp - grecs_bind__bp); \
	(grecs_bind__hold_char) = *grecs_bind__cp; \
	*grecs_bind__cp = '\0'; \
/* %% [3.0] code to copy grecs_bind_text_ptr to grecs_bind_text[] goes here, if %array \ */\
	(grecs_bind__c_buf_p) = grecs_bind__cp;

/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 27
#define YY_END_OF_BUFFER 28
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct grecs_bind__trans_info
	{
	flex_int32_t grecs_bind__verify;
	flex_int32_t grecs_bind__nxt;
	};
static grecs_bind_const flex_int16_t grecs_bind__accept[94] =
    {   0,
        0,    0,    2,    2,    0,    0,   28,   26,   23,   24,
       25,   26,    9,   13,   13,   12,   23,    9,    2,    4,
        3,   27,   20,   22,   27,   23,    0,   17,   14,    0,
        9,    8,   13,    1,   11,   12,   23,    0,    9,    9,
        9,    2,    3,    3,    5,    0,   20,   22,    0,    0,
       21,    0,   18,   15,   16,   13,   11,   10,   11,   12,
        0,    0,    0,    9,    9,    9,   19,    0,    0,    0,
        9,    9,    0,    0,    9,    9,    9,    0,    0,    0,
        9,    6,    9,    9,    0,    6,    0,    0,    9,    7,
        0,    7,    0

    } ;

static grecs_bind_const YY_CHAR grecs_bind__ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    1,    1,    1,    1,    5,
        5,    8,    1,    5,    9,   10,   11,   12,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   10,    5,    1,
        1,    1,    1,   10,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
        1,   15,    1,    1,   14,    1,   14,   14,   14,   14,

       16,   14,   14,   14,   17,   14,   14,   18,   14,   19,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,    5,    1,    5,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static grecs_bind_const YY_CHAR grecs_bind__meta[20] =
    {   0,
        1,    2,    3,    1,    1,    4,    1,    5,    6,    6,
        6,    7,    7,    6,    1,    6,    6,    6,    6
    } ;

static grecs_bind_const flex_uint16_t grecs_bind__base[116] =
    {   0,
        0,   18,   18,   19,   25,   38,  108,  330,   28,  330,
      330,   51,  104,    0,   25,   13,   65,   71,    0,  330,
       26,   87,  330,   32,    0,   41,  100,  330,  330,  102,
      101,  330,    0,  330,  115,  127,    0,  137,    0,  154,
       35,    0,   31,   38,  330,  170,  330,  330,    0,   45,
      330,   98,  330,  330,  330,    0,   97,  330,    0,  178,
        0,   97,   81,  188,    0,   52,  330,   56,   95,   77,
       53,   47,   89,   78,   58,   62,   73,   86,   74,   89,
       75,  330,   76,   84,   80,  330,   82,   67,   48,  330,
       26,  330,  330,  194,  201,  208,  215,  217,  219,  226,

      233,  240,  247,  254,  261,  264,  267,  274,  280,  287,
      294,  301,  308,  315,  322
    } ;

static grecs_bind_const flex_int16_t grecs_bind__def[116] =
    {   0,
       93,    1,   94,   94,   95,   95,   93,   93,   93,   93,
       93,   96,   97,   98,   98,   99,   93,   97,  100,   93,
      101,  102,   93,  103,  104,   93,   96,   93,   93,  105,
       97,   93,  106,   93,   93,  107,   17,   93,   18,   18,
       97,  100,  101,  101,   93,  102,   93,   93,  104,  103,
       93,   93,   93,   93,   93,  106,  108,   93,   35,  107,
       38,  109,   93,   97,   40,   97,   93,   93,  109,   93,
      110,   97,  111,   93,  110,  112,   97,  111,  113,   93,
      112,   93,  112,  114,  113,   93,  113,  115,  114,   93,
      115,   93,    0,   93,   93,   93,   93,   93,   93,   93,

       93,   93,   93,   93,   93,   93,   93,   93,   93,   93,
       93,   93,   93,   93,   93
    } ;

static grecs_bind_const flex_uint16_t grecs_bind__nxt[350] =
    {   0,
        8,    9,   10,    9,   11,   12,   13,   14,   14,   14,
       15,   14,   14,   16,    8,   16,   16,   16,   16,   17,
       20,   20,   33,   33,   18,   21,   21,   23,   92,   26,
       24,   26,   34,   44,   51,   35,   45,   32,   93,   25,
       23,   93,   26,   24,   26,   44,   52,   51,   45,   32,
       90,   66,   25,   28,   32,   32,   29,   68,   76,   52,
       32,   73,   77,   76,   82,   30,   37,   83,   26,   92,
       72,   38,   39,   32,   84,   32,   86,   82,   82,   87,
       83,   83,   86,   40,   86,   87,   90,   87,   41,   47,
       88,   79,   48,   80,   79,   74,   68,   70,   68,   58,

       67,   49,   28,   32,   55,   29,   32,   93,   93,   93,
       93,   93,   93,   93,   30,   57,   57,   58,   57,   57,
       57,   57,   59,   59,   59,   59,   59,   59,   59,   57,
       59,   59,   59,   59,   56,   93,   56,   56,   61,   93,
       93,   93,   93,   93,   93,   93,   93,   93,   93,   62,
       93,   93,   93,   93,   63,   64,   93,   93,   93,   93,
       93,   93,   93,   93,   93,   65,   65,   93,   93,   93,
       93,   31,   47,   93,   93,   48,   93,   93,   93,   93,
       93,   93,   93,   93,   49,   56,   93,   56,   56,   64,
       32,   93,   93,   71,   19,   19,   19,   19,   19,   19,

       19,   22,   22,   22,   22,   22,   22,   22,   27,   27,
       27,   27,   27,   27,   27,   31,   31,   31,   31,   31,
       31,   31,   33,   33,   36,   36,   42,   42,   93,   42,
       93,   42,   42,   43,   43,   93,   43,   43,   43,   43,
       46,   46,   46,   46,   46,   46,   46,   50,   50,   50,
       93,   50,   50,   50,   53,   53,   93,   53,   53,   53,
       53,   54,   54,   54,   54,   54,   54,   54,   56,   56,
       56,   60,   60,   60,   57,   57,   57,   57,   57,   57,
       57,   69,   93,   93,   93,   93,   69,   75,   75,   75,
       75,   75,   75,   75,   78,   78,   93,   78,   78,   78,

       78,   81,   81,   81,   81,   81,   81,   81,   85,   85,
       85,   85,   85,   85,   85,   89,   89,   89,   89,   89,
       89,   89,   91,   91,   91,   91,   91,   91,   91,    7,
       93,   93,   93,   93,   93,   93,   93,   93,   93,   93,
       93,   93,   93,   93,   93,   93,   93,   93,   93
    } ;

static grecs_bind_const flex_int16_t grecs_bind__chk[350] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        3,    4,   16,   16,    2,    3,    4,    5,   91,    9,
        5,    9,   15,   21,   24,   15,   21,   41,   43,    5,
        6,   43,   26,    6,   26,   44,   24,   50,   44,   72,
       89,   41,    6,   12,   66,   71,   12,   68,   71,   50,
       75,   68,   72,   75,   76,   12,   17,   76,   17,   88,
       66,   17,   18,   18,   77,   77,   79,   81,   83,   79,
       81,   83,   85,   18,   87,   85,   84,   87,   18,   22,
       80,   78,   22,   74,   73,   70,   69,   63,   62,   57,

       52,   22,   27,   31,   30,   27,   13,    7,    0,    0,
        0,    0,    0,    0,   27,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   36,    0,   36,   36,   38,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   38,
        0,    0,    0,    0,   38,   40,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   40,   40,    0,    0,    0,
        0,   40,   46,    0,    0,   46,    0,    0,    0,    0,
        0,    0,    0,    0,   46,   60,    0,   60,   60,   64,
       64,    0,    0,   64,   94,   94,   94,   94,   94,   94,

       94,   95,   95,   95,   95,   95,   95,   95,   96,   96,
       96,   96,   96,   96,   96,   97,   97,   97,   97,   97,
       97,   97,   98,   98,   99,   99,  100,  100,    0,  100,
        0,  100,  100,  101,  101,    0,  101,  101,  101,  101,
      102,  102,  102,  102,  102,  102,  102,  103,  103,  103,
        0,  103,  103,  103,  104,  104,    0,  104,  104,  104,
      104,  105,  105,  105,  105,  105,  105,  105,  106,  106,
      106,  107,  107,  107,  108,  108,  108,  108,  108,  108,
      108,  109,    0,    0,    0,    0,  109,  110,  110,  110,
      110,  110,  110,  110,  111,  111,    0,  111,  111,  111,

      111,  112,  112,  112,  112,  112,  112,  112,  113,  113,
      113,  113,  113,  113,  113,  114,  114,  114,  114,  114,
      114,  114,  115,  115,  115,  115,  115,  115,  115,   93,
       93,   93,   93,   93,   93,   93,   93,   93,   93,   93,
       93,   93,   93,   93,   93,   93,   93,   93,   93
    } ;

static grecs_bind__state_type grecs_bind__last_accepting_state;
static char *grecs_bind__last_accepting_cpos;

extern int grecs_bind__flex_debug;
int grecs_bind__flex_debug = 1;

static grecs_bind_const flex_int16_t grecs_bind__rule_linenum[27] =
    {   0,
       55,   56,   57,   58,   59,   61,   65,   70,   71,   72,
       73,   75,   82,   88,   92,   93,   98,  101,  102,  104,
      105,  106,  111,  113,  114,  115
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define grecs_bind_more() grecs_bind_more_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *grecs_bind_text;
#line 1 "bind-lex.l"
/* grecs - Gray's Extensible Configuration System       -*- c -*- */
#define YY_NO_INPUT 1

#line 10 "bind-lex.l"
/* grecs - Gray's Extensible Configuration System
   Copyright (C) 2007-2021 Sergey Poznyakoff

   Grecs is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 3 of the License, or (at your
   option) any later version.

   Grecs is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with Grecs. If not, see <http://www.gnu.org/licenses/>. */

#include <grecs.h>
#include <bind-gram.h>
#include <unistd.h>
#include <fcntl.h>
#include <ctype.h>
#include <stdlib.h>
#include <errno.h>
#include <sys/stat.h>
	
#include <wordsplit.h>

#define YY_USER_ACTION do {						\
		if (YYSTATE == 0) {					\
			grecs_bind_lloc.beg = grecs_current_locus_point;		\
			grecs_bind_lloc.beg.col++;				\
		}							\
  		grecs_current_locus_point.col += grecs_bind_leng;		\
 		grecs_bind_lloc.end = grecs_current_locus_point;			\
   	} while (0);

#line 712 "bind-lex.c"

#define INITIAL 0
#define COMMENT 1
#define STR 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */

static int grecs_bind__init_globals (void );

/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int grecs_bind_lex_destroy (void );

int grecs_bind_get_debug (void );

void grecs_bind_set_debug (int debug_flag  );

YY_EXTRA_TYPE grecs_bind_get_extra (void );

void grecs_bind_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *grecs_bind_get_in (void );

void grecs_bind_set_in  (FILE * _in_str  );

FILE *grecs_bind_get_out (void );

void grecs_bind_set_out  (FILE * _out_str  );

grecs_bind__size_t grecs_bind_get_leng (void );

char *grecs_bind_get_text (void );

int grecs_bind_get_lineno (void );

void grecs_bind_set_lineno (int _line_number  );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int grecs_bind_wrap (void );
#else
extern int grecs_bind_wrap (void );
#endif
#endif

/* %not-for-header */

#ifndef YY_NO_UNPUT
    
#endif
/* %ok-for-header */

/* %endif */

#ifndef grecs_bind_text_ptr
static void grecs_bind__flex_strncpy (char *,grecs_bind_const char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int grecs_bind__flex_strlen (grecs_bind_const char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

#ifdef __cplusplus
static int grecs_bind_input (void );
#else
static int input (void );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( grecs_bind_text, grecs_bind_leng, 1, grecs_bind_out )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->grecs_bind__is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( grecs_bind_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( grecs_bind_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, grecs_bind_in))==0 && ferror(grecs_bind_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(grecs_bind_in); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "grecs_bind_terminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef grecs_bind_terminate
#define grecs_bind_terminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) grecs_bind__fatal_error( msg )
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */

/* %ok-for-header */

/* %not-for-header */

/* %tables-grecs_bind_dmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int grecs_bind_lex (void);

#define YY_DECL int grecs_bind_lex (void)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after grecs_bind_text and grecs_bind_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	if ( grecs_bind_leng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->grecs_bind__at_bol = \
				(grecs_bind_text[grecs_bind_leng - 1] == '\n'); \
	YY_USER_ACTION

/* %not-for-header */

/** The main scanner function which does all the work.
 */
YY_DECL
{
	grecs_bind__state_type grecs_bind__current_state;
	char *grecs_bind__cp, *grecs_bind__bp;
	int grecs_bind__act;
    
	if ( !(grecs_bind__init) )
		{
		(grecs_bind__init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (grecs_bind__start) )
			(grecs_bind__start) = 1;	/* first start state */

		if ( ! grecs_bind_in )
/* %if-c-only */
			grecs_bind_in = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! grecs_bind_out )
/* %if-c-only */
			grecs_bind_out = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			grecs_bind_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				grecs_bind__create_buffer(grecs_bind_in,YY_BUF_SIZE );
		}

		grecs_bind__load_buffer_state( );
		}

	{
/* %% [7.0] user's declarations go here */
#line 53 "bind-lex.l"

         /* C-style comments */
#line 1003 "bind-lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] grecs_bind_more()-related code goes here */
		grecs_bind__cp = (grecs_bind__c_buf_p);

		/* Support of grecs_bind_text. */
		*grecs_bind__cp = (grecs_bind__hold_char);

		/* grecs_bind__bp points to the position in grecs_bind__ch_buf of the start of
		 * the current run.
		 */
		grecs_bind__bp = grecs_bind__cp;

/* %% [9.0] code to set up and find next match goes here */
		grecs_bind__current_state = (grecs_bind__start);
		grecs_bind__current_state += YY_AT_BOL();
grecs_bind__match:
		do
			{
			YY_CHAR grecs_bind__c = grecs_bind__ec[YY_SC_TO_UI(*grecs_bind__cp)] ;
			if ( grecs_bind__accept[grecs_bind__current_state] )
				{
				(grecs_bind__last_accepting_state) = grecs_bind__current_state;
				(grecs_bind__last_accepting_cpos) = grecs_bind__cp;
				}
			while ( grecs_bind__chk[grecs_bind__base[grecs_bind__current_state] + grecs_bind__c] != grecs_bind__current_state )
				{
				grecs_bind__current_state = (int) grecs_bind__def[grecs_bind__current_state];
				if ( grecs_bind__current_state >= 94 )
					grecs_bind__c = grecs_bind__meta[(unsigned int) grecs_bind__c];
				}
			grecs_bind__current_state = grecs_bind__nxt[grecs_bind__base[grecs_bind__current_state] + (unsigned int) grecs_bind__c];
			++grecs_bind__cp;
			}
		while ( grecs_bind__base[grecs_bind__current_state] != 330 );

grecs_bind__find_action:
/* %% [10.0] code to find the action number goes here */
		grecs_bind__act = grecs_bind__accept[grecs_bind__current_state];
		if ( grecs_bind__act == 0 )
			{ /* have to back up */
			grecs_bind__cp = (grecs_bind__last_accepting_cpos);
			grecs_bind__current_state = (grecs_bind__last_accepting_state);
			grecs_bind__act = grecs_bind__accept[grecs_bind__current_state];
			}

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for grecs_bind_lineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( grecs_bind__flex_debug )
			{
			if ( grecs_bind__act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( grecs_bind__act < 27 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)grecs_bind__rule_linenum[grecs_bind__act], grecs_bind_text );
			else if ( grecs_bind__act == 27 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         grecs_bind_text );
			else if ( grecs_bind__act == 28 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( grecs_bind__act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*grecs_bind__cp = (grecs_bind__hold_char);
			grecs_bind__cp = (grecs_bind__last_accepting_cpos);
			grecs_bind__current_state = (grecs_bind__last_accepting_state);
			goto grecs_bind__find_action;

case 1:
YY_RULE_SETUP
#line 55 "bind-lex.l"
BEGIN(COMMENT);
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 56 "bind-lex.l"
/* eat anything that's not a '*' */
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 57 "bind-lex.l"
/* eat up '*'s not followed by '/'s */
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 58 "bind-lex.l"
grecs_locus_point_advance_line(grecs_current_locus_point);
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 59 "bind-lex.l"
BEGIN(INITIAL);
	YY_BREAK
/* Line directive */
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 61 "bind-lex.l"
{ grecs_parse_line_directive_cpp(grecs_bind_text,
						    &grecs_bind_lloc,
						    &grecs_current_locus_point,
						    NULL); }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 65 "bind-lex.l"
{ grecs_parse_line_directive(grecs_bind_text,
						    &grecs_bind_lloc,
						    &grecs_current_locus_point,
						    NULL); }
	YY_BREAK
/* End-of-line comments */
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 70 "bind-lex.l"
{ grecs_locus_point_advance_line(grecs_current_locus_point); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 71 "bind-lex.l"
/* end-of-file comment */;
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 72 "bind-lex.l"
{ grecs_locus_point_advance_line(grecs_current_locus_point); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 73 "bind-lex.l"
/* end-of-file comment */;
	YY_BREAK
/* Identifiers */
case 12:
YY_RULE_SETUP
#line 75 "bind-lex.l"
{ grecs_line_begin();
	    grecs_line_add(grecs_bind_text, grecs_bind_leng);
	    grecs_bind_lval.string = grecs_line_finish();
	    return strcmp(grecs_bind_lval.string, "controls") == 0 ?
		    BIND_CONTROLS : BIND_IDENT;
          }
	YY_BREAK
/* Strings */
case 13:
YY_RULE_SETUP
#line 82 "bind-lex.l"
{
	                   grecs_line_begin();
	                   grecs_line_add(grecs_bind_text, grecs_bind_leng);
                           grecs_bind_lval.string = grecs_line_finish();
                           return BIND_STRING; }
	YY_BREAK
/* Quoted strings */
case 14:
YY_RULE_SETUP
#line 88 "bind-lex.l"
{ grecs_line_begin();
                        grecs_line_add(grecs_bind_text + 1, grecs_bind_leng - 2);
                        grecs_bind_lval.string = grecs_line_finish();
                        return BIND_STRING; }
	YY_BREAK
case 15:
#line 93 "bind-lex.l"
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 93 "bind-lex.l"
{ BEGIN(STR);
                         grecs_line_begin();
		         grecs_line_acc_grow_unescape_last(grecs_bind_text + 1,
                                                           grecs_bind_leng - 1, 
                                                           &grecs_bind_lloc); }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 98 "bind-lex.l"
{ BEGIN(STR);
                         grecs_line_begin();
		         grecs_line_acc_grow(grecs_bind_text + 1, grecs_bind_leng - 1); }
	YY_BREAK
case 18:
#line 102 "bind-lex.l"
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 102 "bind-lex.l"
{ grecs_line_acc_grow_unescape_last(grecs_bind_text, grecs_bind_leng, 
                                                          &grecs_bind_lloc); }
	YY_BREAK
case 20:
/* rule 20 can match eol */
#line 105 "bind-lex.l"
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 105 "bind-lex.l"
{ grecs_line_acc_grow(grecs_bind_text, grecs_bind_leng); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 106 "bind-lex.l"
{ BEGIN(INITIAL);
                        if (grecs_bind_leng > 1) 
				grecs_line_add(grecs_bind_text, grecs_bind_leng - 1); 
                        grecs_bind_lval.string = grecs_line_finish();
		        return BIND_STRING; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 111 "bind-lex.l"
;
	YY_BREAK
/* Other tokens */
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 113 "bind-lex.l"
{ grecs_locus_point_advance_line(grecs_current_locus_point); } 
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 114 "bind-lex.l"
return grecs_bind_text[0];
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 115 "bind-lex.l"
{ if (isascii(grecs_bind_text[0]) && isprint(grecs_bind_text[0]))
		grecs_error(&grecs_bind_lloc, 0,
			     _("stray character %c"), grecs_bind_text[0]);
           else
                grecs_error(&grecs_bind_lloc, 0, _("stray character \\%03o"),
		   	    (unsigned char) grecs_bind_text[0]); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 121 "bind-lex.l"
ECHO;
	YY_BREAK
#line 1261 "bind-lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(COMMENT):
case YY_STATE_EOF(STR):
	grecs_bind_terminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int grecs_bind__amount_of_matched_text = (int) (grecs_bind__cp - (grecs_bind_text_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*grecs_bind__cp = (grecs_bind__hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->grecs_bind__buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed grecs_bind_in at a new source and called
			 * grecs_bind_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(grecs_bind__n_chars) = YY_CURRENT_BUFFER_LVALUE->grecs_bind__n_chars;
/* %if-c-only */
			YY_CURRENT_BUFFER_LVALUE->grecs_bind__input_file = grecs_bind_in;
/* %endif */
/* %if-c++-only */
/* %endif */
			YY_CURRENT_BUFFER_LVALUE->grecs_bind__buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for grecs_bind__c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since grecs_bind__c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (grecs_bind__c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf[(grecs_bind__n_chars)] )
			{ /* This was really a NUL. */
			grecs_bind__state_type grecs_bind__next_state;

			(grecs_bind__c_buf_p) = (grecs_bind_text_ptr) + grecs_bind__amount_of_matched_text;

			grecs_bind__current_state = grecs_bind__get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * grecs_bind__get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			grecs_bind__next_state = grecs_bind__try_NUL_trans( grecs_bind__current_state );

			grecs_bind__bp = (grecs_bind_text_ptr) + YY_MORE_ADJ;

			if ( grecs_bind__next_state )
				{
				/* Consume the NUL. */
				grecs_bind__cp = ++(grecs_bind__c_buf_p);
				grecs_bind__current_state = grecs_bind__next_state;
				goto grecs_bind__match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up grecs_bind__cp goes here */
				grecs_bind__cp = (grecs_bind__c_buf_p);
				goto grecs_bind__find_action;
				}
			}

		else switch ( grecs_bind__get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(grecs_bind__did_buffer_switch_on_eof) = 0;

				if ( grecs_bind_wrap( ) )
					{
					/* Note: because we've taken care in
					 * grecs_bind__get_next_buffer() to have set up
					 * grecs_bind_text, we can now set up
					 * grecs_bind__c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(grecs_bind__c_buf_p) = (grecs_bind_text_ptr) + YY_MORE_ADJ;

					grecs_bind__act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (grecs_bind__did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(grecs_bind__c_buf_p) =
					(grecs_bind_text_ptr) + grecs_bind__amount_of_matched_text;

				grecs_bind__current_state = grecs_bind__get_previous_state(  );

				grecs_bind__cp = (grecs_bind__c_buf_p);
				grecs_bind__bp = (grecs_bind_text_ptr) + YY_MORE_ADJ;
				goto grecs_bind__match;

			case EOB_ACT_LAST_MATCH:
				(grecs_bind__c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf[(grecs_bind__n_chars)];

				grecs_bind__current_state = grecs_bind__get_previous_state(  );

				grecs_bind__cp = (grecs_bind__c_buf_p);
				grecs_bind__bp = (grecs_bind_text_ptr) + YY_MORE_ADJ;
				goto grecs_bind__find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of grecs_bind_lex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */

/* %ok-for-header */

/* %endif */

/* grecs_bind__get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int grecs_bind__get_next_buffer (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf;
	char *source = (grecs_bind_text_ptr);
	grecs_bind__size_t number_to_move, i;
	int ret_val;

	if ( (grecs_bind__c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf[(grecs_bind__n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->grecs_bind__fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (grecs_bind__c_buf_p) - (grecs_bind_text_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (grecs_bind__size_t) ((grecs_bind__c_buf_p) - (grecs_bind_text_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->grecs_bind__buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->grecs_bind__n_chars = (grecs_bind__n_chars) = 0;

	else
		{
			grecs_bind__size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->grecs_bind__buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int grecs_bind__c_buf_p_offset =
				(int) ((grecs_bind__c_buf_p) - b->grecs_bind__ch_buf);

			if ( b->grecs_bind__is_our_buffer )
				{
				grecs_bind__size_t new_size = b->grecs_bind__buf_size * 2;

				if ( new_size <= 0 )
					b->grecs_bind__buf_size += b->grecs_bind__buf_size / 8;
				else
					b->grecs_bind__buf_size *= 2;

				b->grecs_bind__ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					grecs_bind_realloc((void *) b->grecs_bind__ch_buf,b->grecs_bind__buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->grecs_bind__ch_buf = 0;

			if ( ! b->grecs_bind__ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(grecs_bind__c_buf_p) = &b->grecs_bind__ch_buf[grecs_bind__c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->grecs_bind__buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf[number_to_move]),
			(grecs_bind__n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->grecs_bind__n_chars = (grecs_bind__n_chars);
		}

	if ( (grecs_bind__n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			grecs_bind_restart(grecs_bind_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->grecs_bind__buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((grecs_bind__size_t) ((grecs_bind__n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->grecs_bind__buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		grecs_bind__size_t new_size = (grecs_bind__n_chars) + number_to_move + ((grecs_bind__n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf = (char *) grecs_bind_realloc((void *) YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_bind__get_next_buffer()" );
	}

	(grecs_bind__n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf[(grecs_bind__n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf[(grecs_bind__n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(grecs_bind_text_ptr) = &YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf[0];

	return ret_val;
}

/* grecs_bind__get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */

    static grecs_bind__state_type grecs_bind__get_previous_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	grecs_bind__state_type grecs_bind__current_state;
	char *grecs_bind__cp;
    
/* %% [15.0] code to get the start state into grecs_bind__current_state goes here */
	grecs_bind__current_state = (grecs_bind__start);
	grecs_bind__current_state += YY_AT_BOL();

	for ( grecs_bind__cp = (grecs_bind_text_ptr) + YY_MORE_ADJ; grecs_bind__cp < (grecs_bind__c_buf_p); ++grecs_bind__cp )
		{
/* %% [16.0] code to find the next state goes here */
		YY_CHAR grecs_bind__c = (*grecs_bind__cp ? grecs_bind__ec[YY_SC_TO_UI(*grecs_bind__cp)] : 1);
		if ( grecs_bind__accept[grecs_bind__current_state] )
			{
			(grecs_bind__last_accepting_state) = grecs_bind__current_state;
			(grecs_bind__last_accepting_cpos) = grecs_bind__cp;
			}
		while ( grecs_bind__chk[grecs_bind__base[grecs_bind__current_state] + grecs_bind__c] != grecs_bind__current_state )
			{
			grecs_bind__current_state = (int) grecs_bind__def[grecs_bind__current_state];
			if ( grecs_bind__current_state >= 94 )
				grecs_bind__c = grecs_bind__meta[(unsigned int) grecs_bind__c];
			}
		grecs_bind__current_state = grecs_bind__nxt[grecs_bind__base[grecs_bind__current_state] + (unsigned int) grecs_bind__c];
		}

	return grecs_bind__current_state;
}

/* grecs_bind__try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = grecs_bind__try_NUL_trans( current_state );
 */
/* %if-c-only */
    static grecs_bind__state_type grecs_bind__try_NUL_trans  (grecs_bind__state_type grecs_bind__current_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	int grecs_bind__is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	char *grecs_bind__cp = (grecs_bind__c_buf_p);

	YY_CHAR grecs_bind__c = 1;
	if ( grecs_bind__accept[grecs_bind__current_state] )
		{
		(grecs_bind__last_accepting_state) = grecs_bind__current_state;
		(grecs_bind__last_accepting_cpos) = grecs_bind__cp;
		}
	while ( grecs_bind__chk[grecs_bind__base[grecs_bind__current_state] + grecs_bind__c] != grecs_bind__current_state )
		{
		grecs_bind__current_state = (int) grecs_bind__def[grecs_bind__current_state];
		if ( grecs_bind__current_state >= 94 )
			grecs_bind__c = grecs_bind__meta[(unsigned int) grecs_bind__c];
		}
	grecs_bind__current_state = grecs_bind__nxt[grecs_bind__base[grecs_bind__current_state] + (unsigned int) grecs_bind__c];
	grecs_bind__is_jam = (grecs_bind__current_state == 93);

		return grecs_bind__is_jam ? 0 : grecs_bind__current_state;
}

#ifndef YY_NO_UNPUT
/* %if-c-only */

/* %endif */
#endif

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int grecs_bind_input (void)
#else
    static int input  (void)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    
	*(grecs_bind__c_buf_p) = (grecs_bind__hold_char);

	if ( *(grecs_bind__c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* grecs_bind__c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (grecs_bind__c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->grecs_bind__ch_buf[(grecs_bind__n_chars)] )
			/* This was really a NUL. */
			*(grecs_bind__c_buf_p) = '\0';

		else
			{ /* need more input */
			grecs_bind__size_t offset = (grecs_bind__c_buf_p) - (grecs_bind_text_ptr);
			++(grecs_bind__c_buf_p);

			switch ( grecs_bind__get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because grecs_bind__g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					grecs_bind_restart(grecs_bind_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( grecs_bind_wrap( ) )
						return EOF;

					if ( ! (grecs_bind__did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return grecs_bind_input();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(grecs_bind__c_buf_p) = (grecs_bind_text_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (grecs_bind__c_buf_p);	/* cast for 8-bit char's */
	*(grecs_bind__c_buf_p) = '\0';	/* preserve grecs_bind_text */
	(grecs_bind__hold_char) = *++(grecs_bind__c_buf_p);

/* %% [19.0] update BOL and grecs_bind_lineno */
	YY_CURRENT_BUFFER_LVALUE->grecs_bind__at_bol = (c == '\n');

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void grecs_bind_restart  (FILE * input_file )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        grecs_bind_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            grecs_bind__create_buffer(grecs_bind_in,YY_BUF_SIZE );
	}

	grecs_bind__init_buffer(YY_CURRENT_BUFFER,input_file );
	grecs_bind__load_buffer_state( );
}

/* %if-c++-only */
/* %endif */

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
    void grecs_bind__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		grecs_bind_pop_buffer_state();
	 *		grecs_bind_push_buffer_state(new_buffer);
     */
	grecs_bind_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(grecs_bind__c_buf_p) = (grecs_bind__hold_char);
		YY_CURRENT_BUFFER_LVALUE->grecs_bind__buf_pos = (grecs_bind__c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->grecs_bind__n_chars = (grecs_bind__n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	grecs_bind__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (grecs_bind_wrap()) processing, but the only time this flag
	 * is looked at is after grecs_bind_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(grecs_bind__did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
static void grecs_bind__load_buffer_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	(grecs_bind__n_chars) = YY_CURRENT_BUFFER_LVALUE->grecs_bind__n_chars;
	(grecs_bind_text_ptr) = (grecs_bind__c_buf_p) = YY_CURRENT_BUFFER_LVALUE->grecs_bind__buf_pos;
/* %if-c-only */
	grecs_bind_in = YY_CURRENT_BUFFER_LVALUE->grecs_bind__input_file;
/* %endif */
/* %if-c++-only */
/* %endif */
	(grecs_bind__hold_char) = *(grecs_bind__c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE grecs_bind__create_buffer  (FILE * file, int  size )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) grecs_bind_alloc(sizeof( struct grecs_bind__buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_bind__create_buffer()" );

	b->grecs_bind__buf_size = (grecs_bind__size_t)size;

	/* grecs_bind__ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->grecs_bind__ch_buf = (char *) grecs_bind_alloc(b->grecs_bind__buf_size + 2  );
	if ( ! b->grecs_bind__ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_bind__create_buffer()" );

	b->grecs_bind__is_our_buffer = 1;

	grecs_bind__init_buffer(b,file );

	return b;
}

/* %if-c++-only */
/* %endif */

/** Destroy the buffer.
 * @param b a buffer created with grecs_bind__create_buffer()
 * 
 */
/* %if-c-only */
    void grecs_bind__delete_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->grecs_bind__is_our_buffer )
		grecs_bind_free((void *) b->grecs_bind__ch_buf  );

	grecs_bind_free((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a grecs_bind_restart() or at EOF.
 */
/* %if-c-only */
    static void grecs_bind__init_buffer  (YY_BUFFER_STATE  b, FILE * file )
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    
	grecs_bind__flush_buffer(b );

/* %if-c-only */
	b->grecs_bind__input_file = file;
/* %endif */
/* %if-c++-only */
/* %endif */
	b->grecs_bind__fill_buffer = 1;

    /* If b is the current buffer, then grecs_bind__init_buffer was _probably_
     * called from grecs_bind_restart() or through grecs_bind__get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->grecs_bind__bs_lineno = 1;
        b->grecs_bind__bs_column = 0;
    }

/* %if-c-only */

        b->grecs_bind__is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
    void grecs_bind__flush_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( ! b )
		return;

	b->grecs_bind__n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->grecs_bind__ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->grecs_bind__ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->grecs_bind__buf_pos = &b->grecs_bind__ch_buf[0];

	b->grecs_bind__at_bol = 1;
	b->grecs_bind__buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		grecs_bind__load_buffer_state( );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
void grecs_bind_push_buffer_state (YY_BUFFER_STATE new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	grecs_bind_ensure_buffer_stack();

	/* This block is copied from grecs_bind__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(grecs_bind__c_buf_p) = (grecs_bind__hold_char);
		YY_CURRENT_BUFFER_LVALUE->grecs_bind__buf_pos = (grecs_bind__c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->grecs_bind__n_chars = (grecs_bind__n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(grecs_bind__buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from grecs_bind__switch_to_buffer. */
	grecs_bind__load_buffer_state( );
	(grecs_bind__did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
void grecs_bind_pop_buffer_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	grecs_bind__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((grecs_bind__buffer_stack_top) > 0)
		--(grecs_bind__buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		grecs_bind__load_buffer_state( );
		(grecs_bind__did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void grecs_bind_ensure_buffer_stack (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	grecs_bind__size_t num_to_alloc;
    
	if (!(grecs_bind__buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1; // After all that talk, this was set to 1 anyways...
		(grecs_bind__buffer_stack) = (struct grecs_bind__buffer_state**)grecs_bind_alloc
								(num_to_alloc * sizeof(struct grecs_bind__buffer_state*)
								);
		if ( ! (grecs_bind__buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_bind_ensure_buffer_stack()" );
								  
		memset((grecs_bind__buffer_stack), 0, num_to_alloc * sizeof(struct grecs_bind__buffer_state*));
				
		(grecs_bind__buffer_stack_max) = num_to_alloc;
		(grecs_bind__buffer_stack_top) = 0;
		return;
	}

	if ((grecs_bind__buffer_stack_top) >= ((grecs_bind__buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		grecs_bind__size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (grecs_bind__buffer_stack_max) + grow_size;
		(grecs_bind__buffer_stack) = (struct grecs_bind__buffer_state**)grecs_bind_realloc
								((grecs_bind__buffer_stack),
								num_to_alloc * sizeof(struct grecs_bind__buffer_state*)
								);
		if ( ! (grecs_bind__buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_bind_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((grecs_bind__buffer_stack) + (grecs_bind__buffer_stack_max), 0, grow_size * sizeof(struct grecs_bind__buffer_state*));
		(grecs_bind__buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE grecs_bind__scan_buffer  (char * base, grecs_bind__size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) grecs_bind_alloc(sizeof( struct grecs_bind__buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_bind__scan_buffer()" );

	b->grecs_bind__buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->grecs_bind__buf_pos = b->grecs_bind__ch_buf = base;
	b->grecs_bind__is_our_buffer = 0;
	b->grecs_bind__input_file = 0;
	b->grecs_bind__n_chars = b->grecs_bind__buf_size;
	b->grecs_bind__is_interactive = 0;
	b->grecs_bind__at_bol = 1;
	b->grecs_bind__fill_buffer = 0;
	b->grecs_bind__buffer_status = YY_BUFFER_NEW;

	grecs_bind__switch_to_buffer(b  );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to grecs_bind_lex() will
 * scan from a @e copy of @a str.
 * @param grecs_bind_str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       grecs_bind__scan_bytes() instead.
 */
YY_BUFFER_STATE grecs_bind__scan_string (grecs_bind_const char * grecs_bind_str )
{
    
	return grecs_bind__scan_bytes(grecs_bind_str,strlen(grecs_bind_str) );
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to grecs_bind_lex() will
 * scan from a @e copy of @a bytes.
 * @param grecs_bind_bytes the byte buffer to scan
 * @param _grecs_bind_bytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE grecs_bind__scan_bytes  (grecs_bind_const char * grecs_bind_bytes, grecs_bind__size_t  _grecs_bind_bytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	grecs_bind__size_t n;
	grecs_bind__size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _grecs_bind_bytes_len + 2;
	buf = (char *) grecs_bind_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_bind__scan_bytes()" );

	for ( i = 0; i < _grecs_bind_bytes_len; ++i )
		buf[i] = grecs_bind_bytes[i];

	buf[_grecs_bind_bytes_len] = buf[_grecs_bind_bytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = grecs_bind__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in grecs_bind__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->grecs_bind__is_our_buffer = 1;

	return b;
}
/* %endif */

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void grecs_bind__fatal_error (grecs_bind_const char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine grecs_bind_less() so it works in section 3 code. */

#undef grecs_bind_less
#define grecs_bind_less(n) \
	do \
		{ \
		/* Undo effects of setting up grecs_bind_text. */ \
        int grecs_bind_less_macro_arg = (n); \
        YY_LESS_LINENO(grecs_bind_less_macro_arg);\
		grecs_bind_text[grecs_bind_leng] = (grecs_bind__hold_char); \
		(grecs_bind__c_buf_p) = grecs_bind_text + grecs_bind_less_macro_arg; \
		(grecs_bind__hold_char) = *(grecs_bind__c_buf_p); \
		*(grecs_bind__c_buf_p) = '\0'; \
		grecs_bind_leng = grecs_bind_less_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */

/** Get the current line number.
 * 
 */
int grecs_bind_get_lineno  (void)
{
        
    return grecs_bind_lineno;
}

/** Get the input stream.
 * 
 */
FILE *grecs_bind_get_in  (void)
{
        return grecs_bind_in;
}

/** Get the output stream.
 * 
 */
FILE *grecs_bind_get_out  (void)
{
        return grecs_bind_out;
}

/** Get the length of the current token.
 * 
 */
grecs_bind__size_t grecs_bind_get_leng  (void)
{
        return grecs_bind_leng;
}

/** Get the current token.
 * 
 */

char *grecs_bind_get_text  (void)
{
        return grecs_bind_text;
}

/* %if-reentrant */
/* %endif */

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void grecs_bind_set_lineno (int  _line_number )
{
    
    grecs_bind_lineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see grecs_bind__switch_to_buffer
 */
void grecs_bind_set_in (FILE *  _in_str )
{
        grecs_bind_in = _in_str ;
}

void grecs_bind_set_out (FILE *  _out_str )
{
        grecs_bind_out = _out_str ;
}

int grecs_bind_get_debug  (void)
{
        return grecs_bind__flex_debug;
}

void grecs_bind_set_debug (int  _bdebug )
{
        grecs_bind__flex_debug = _bdebug ;
}

/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
static int grecs_bind__init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from grecs_bind_lex_destroy(), so don't allocate here.
     */

    (grecs_bind__buffer_stack) = 0;
    (grecs_bind__buffer_stack_top) = 0;
    (grecs_bind__buffer_stack_max) = 0;
    (grecs_bind__c_buf_p) = (char *) 0;
    (grecs_bind__init) = 0;
    (grecs_bind__start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    grecs_bind_in = stdin;
    grecs_bind_out = stdout;
#else
    grecs_bind_in = (FILE *) 0;
    grecs_bind_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * grecs_bind_lex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* grecs_bind_lex_destroy is for both reentrant and non-reentrant scanners. */
int grecs_bind_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		grecs_bind__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		grecs_bind_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	grecs_bind_free((grecs_bind__buffer_stack) );
	(grecs_bind__buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * grecs_bind_lex() is called, initialization will occur. */
    grecs_bind__init_globals( );

/* %if-reentrant */
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef grecs_bind_text_ptr
static void grecs_bind__flex_strncpy (char* s1, grecs_bind_const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int grecs_bind__flex_strlen (grecs_bind_const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *grecs_bind_alloc (grecs_bind__size_t  size )
{
			return (void *) malloc( size );
}

void *grecs_bind_realloc  (void * ptr, grecs_bind__size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void grecs_bind_free (void * ptr )
{
			free( (char *) ptr );	/* see grecs_bind_realloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-grecs_bind_tables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "grecs_bind_tables"
/* %endif */

/* %ok-for-header */

#line 121 "bind-lex.l"



struct bind_input_context {
	ino_t i_node;
	dev_t i_dev;
        struct grecs_locus_point point;
	grecs_locus_t locus;		/* Current input location */
	YY_BUFFER_STATE state;
	FILE *input;
};

static struct grecs_list *input_stack;
static ino_t i_node;
static dev_t i_dev;

static void
free_context(void *ptr)
{
	free(ptr);
}

static int
cmp_context(const void *a, const void *b)
{
	struct bind_input_context const *ac = a;
	struct bind_input_context const *bc = b;

	return !(ac->i_node == bc->i_node && ac->i_dev == bc->i_dev);
}

static int
_push_context(const char *name, ino_t i_node, dev_t i_dev, grecs_locus_t *loc)
{
	struct bind_input_context ctx, *pctx;
	
	if (!input_stack) {
		input_stack = grecs_list_create();
		input_stack->free_entry = free_context;
		input_stack->cmp = cmp_context;
	} else {
		ctx.i_dev = i_dev;
		ctx.i_node = i_node;
		pctx = grecs_list_locate(input_stack, &ctx);
		if (pctx) {
			grecs_error(&grecs_bind_lloc, 0,
				    _("%s has already been included"), name);
			grecs_error(&pctx->locus, 0,
			    _("this is where the previous inclusion occurred"));
			return 1;
		}

		pctx = grecs_malloc(sizeof(*pctx));
		pctx->i_node = i_node;
		pctx->i_dev = i_dev;
                if (loc)
                        pctx->locus = *loc;
                else
                        memset(&pctx->locus, 0, sizeof(pctx->locus)); /* FIXME */
		pctx->point = grecs_current_locus_point;
		pctx->state = YY_CURRENT_BUFFER;
		pctx->input = grecs_bind_in;
		grecs_list_push(input_stack, pctx);
	}
	return 0;
}

static int
_pop_context()
{
	struct bind_input_context *pctx;

	if (!grecs_bind_in)
		return 1;
        if (grecs_preprocessor)
                pclose(grecs_bind_in);
        else
	        fclose(grecs_bind_in);
	pctx = grecs_list_pop(input_stack);
	if (!pctx) {
		grecs_bind_in = NULL;
		return 1;
	}
	i_node = pctx->i_node;
	i_dev = pctx->i_dev;
	grecs_current_locus_point = pctx->point;
	grecs_bind_in = pctx->input;
	grecs_bind__delete_buffer(YY_CURRENT_BUFFER);
	grecs_bind__switch_to_buffer(pctx->state);
	grecs_free(pctx);
	return 0;
}

int
grecs_bind_wrap()
{
	return _pop_context();
}

int
grecs_bind_new_source(const char *name, grecs_locus_t *loc)
{
	struct stat st;
	FILE *fp;
	
	if (access(name, F_OK)) {
		int ec = errno;
		char *tmp = grecs_find_include_file(name, 0);
		if (!tmp) {
			grecs_error(loc, ec, _("cannot open `%s'"), name);
			return 1;
		}
		name = grecs_install_text(tmp);
		free(tmp);
	}
	
	fp = fopen(name, "r");
	if (!fp) {
		grecs_error(loc, errno, _("cannot open `%s'"), name);
		return 1;
 	}
	if (fstat(fileno(fp), &st)) {
		grecs_error(loc, errno, _("can't state %s"), name);
		fclose(fp);
		return 1;
	}
        if (grecs_preprocessor) {
                char *cmd = NULL;
                size_t size = 0;

		fclose(fp);
                if (grecs_asprintf(&cmd, &size, "%s \"%s\"",
                                   grecs_preprocessor, name))
                        grecs_alloc_die();
              
                fp = popen(cmd, "r");
                if (!fp) {
		        grecs_error(loc, errno, _("cannot open `%s'"), cmd);
                        grecs_free(cmd);
                        return 1;
                }
                grecs_free(cmd);
        }

	if (_push_context(name, st.st_ino, st.st_dev, loc)) {
		return 1;
	}
	i_node = st.st_ino;
	i_dev = st.st_dev;
	grecs_bind_in = fp;
	grecs_bind__switch_to_buffer(grecs_bind__create_buffer(grecs_bind_in,YY_BUF_SIZE));
	grecs_current_locus_point.file = grecs_install_text(name);
	grecs_current_locus_point.line = 1;
	grecs_current_locus_point.col = 0;
	return 0;
}

void
grecs_bind_close_sources()
{
	while (!_pop_context())
		;
	grecs_list_free(input_stack);
	input_stack = NULL;
}

